﻿using MySql.Data.MySqlClient;
using Pokedex.Entidade;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Pokedex.Repository
{
    internal class PokemonRepository
    {
        private readonly string _connectionString;

        public PokemonRepository(string connectionString)
        {
            _connectionString = connectionString;
            
        }

        public List<Pokemon> ObterTodosPokemons()
        {
            List<Pokemon> pokemons = new List<Pokemon>();
            using (var connection = new MySqlConnection(_connectionString))
            {
                connection.Open();
                string query = "SELECT * FROM pokemon";
                using (var command = new MySqlCommand(query, connection))
                using (var reader = command.ExecuteReader())
                {
                    while (reader.Read())
                    {
                        pokemons.Add(new Pokemon
                        {
                            IdPokemon = reader.GetInt32("id_pokemon"),
                            Nome = reader.GetString("nome"),
                            Descricao = reader.GetString("descricao"),
                            Tipo1 = reader.GetInt32("tipo1"),
                            Tipo2 = reader.GetInt32("tipo2")
                        });
                    }
                }
            }
            return pokemons;
        }

        public int InserirPokemon(Pokemon pokemon)
        {
            int affectedRows = -1;
            using (var connection = new MySqlConnection(_connectionString))
            {
                connection.Open();
                string query = "INSERT INTO pokemon(id_pokemon, nome, descricao, tipo1, tipo2) VALUES (@idPokemon, @nome, @descricao, @tipo1, @tipo2)";
                using (var command = new MySqlCommand(query, connection))
                {
                    command.Parameters.AddWithValue("@nome", pokemon.Nome);
                    command.Parameters.AddWithValue("@descricao", pokemon.Descricao);
                    command.Parameters.AddWithValue("@tipo1", pokemon.Tipo1);
                    command.Parameters.AddWithValue("@tipo2", pokemon.Tipo2);
                    command.Parameters.AddWithValue("@idPokemon", pokemon.IdPokemon);
                    affectedRows = command.ExecuteNonQuery();
                }
            }
            return affectedRows;
        }

        public int AtualizarPokemon(Pokemon pokemon)
        {
            int affectedRows = -1;
            using (var connection = new MySqlConnection(_connectionString))
            {
                connection.Open();
                string query = "UPDATE pokemon SET nome = @nome, descricao = @descricao, tipo1 = @tipo1, tipo2 = @tipo2 WHERE id_pokemon = @idPokemon";
                using (var command = new MySqlCommand(query, connection))
                {
                    command.Parameters.AddWithValue("@nome", pokemon.Nome);
                    command.Parameters.AddWithValue("@descricao", pokemon.Descricao);
                    command.Parameters.AddWithValue("@tipo1", pokemon.Tipo1);
                    command.Parameters.AddWithValue("@tipo2", pokemon.Tipo2);
                    command.Parameters.AddWithValue("@idPokemon", pokemon.IdPokemon);
                    affectedRows = command.ExecuteNonQuery();
                }
            }
            return affectedRows;
        }

        public int RemoverPokemon(int idPokemon)
        {
            int affectedRows = -1;
            using (var connection = new MySqlConnection(_connectionString))
            {
                connection.Open();
                string query = "DELETE FROM pokemon WHERE id_pokemon = @idPokemon";
                using (var command = new MySqlCommand(query, connection))
                {
                    command.Parameters.AddWithValue("@idPokemon", idPokemon);
                    affectedRows = command.ExecuteNonQuery();
                }
            }
            return affectedRows;
        }

        public List<Pokemon> ObterTodosPokemonsPorTipo(int idTipo)
        {
            List<Pokemon> pokemons = new List<Pokemon>();
            using (var connection = new MySqlConnection(_connectionString))
            {
                connection.Open();
                string query = $"SELECT * FROM pokemon WHERE tipo1 = {idTipo} OR tipo2 = {idTipo}";
                using (var command = new MySqlCommand(query, connection))
                using (var reader = command.ExecuteReader())
                {
                    while (reader.Read())
                    {
                        pokemons.Add(new Pokemon
                        {
                            IdPokemon = reader.GetInt32("id_pokemon"),
                            Nome = reader.GetString("nome"),
                            Descricao = reader.GetString("descricao"),
                            Tipo1 = reader.GetInt32("tipo1"),
                            Tipo2 = reader.GetInt32("tipo2")
                        });
                    }
                }
            }
            return pokemons;
        }
    }
}
